@@ -598,8 +598,8 @@ static void con_ic_connection_statistics_cb(DBusPendingCall *pending,
 {
 
 	const char *iap_id;
-	dbus_uint32_t time_active, signal_strength, rx_packets, tx_packets,
-		rx_bytes, tx_bytes;
+	dbus_uint32_t time_active = 0, signal_strength = 0,  rx_packets = 0,
+	  tx_packets = 0, rx_bytes = 0, tx_bytes = 0;
 	DBusMessage *reply = NULL;
 	DBusError error;
 	ConIcConnection *connection = CON_IC_CONNECTION(user_data);
@@ -613,27 +613,23 @@ static void con_ic_connection_statistics_cb(DBusPendingCall *pending,
 		goto error;
 	}
 	
-	if (dbus_set_error_from_message(&error, reply)) {
-		goto error;
-	}
-
-	if (!dbus_message_get_args(reply, &error,
-				   DBUS_TYPE_STRING, &iap_id,
-				   DBUS_TYPE_UINT32, &time_active,
-				   DBUS_TYPE_UINT32, &signal_strength,
-				   DBUS_TYPE_UINT32, &rx_packets,
-				   DBUS_TYPE_UINT32, &tx_packets,
-				   DBUS_TYPE_UINT32, &rx_bytes,
-				   DBUS_TYPE_UINT32, &tx_bytes,
-				   DBUS_TYPE_INVALID)) {
-		goto error;
-	}
+	/* if an error is sent or reading arguments fail we'll fall back to
+	   default values */
+	if (!dbus_set_error_from_message(&error, reply))
+	  dbus_message_get_args(reply, &error,
+				DBUS_TYPE_STRING, &iap_id,
+				DBUS_TYPE_UINT32, &time_active,
+				DBUS_TYPE_UINT32, &signal_strength,
+				DBUS_TYPE_UINT32, &rx_packets,
+				DBUS_TYPE_UINT32, &tx_packets,
+				DBUS_TYPE_UINT32, &rx_bytes,
+				DBUS_TYPE_UINT32, &tx_bytes,
+				DBUS_TYPE_INVALID);
 
 	event = con_ic_statistics_event_new();
-	g_assert(CON_IC_IS_STATISTICS_EVENT(event));
 
-/* 	con_ic_event_set_iap_id(CON_IC_EVENT(event), iap_id); */
-	/* FIXME: add bearer */
+	con_ic_event_set_iap_id(CON_IC_EVENT(event), connection->iap_id);
+	con_ic_event_set_bearer_type(CON_IC_EVENT(event), connection->bearer);
 	con_ic_statistics_event_set_time_active(event, time_active);
 	con_ic_statistics_event_set_signal_strength(event, signal_strength);
 	con_ic_statistics_event_set_rx_packets(event, rx_packets);
@@ -641,8 +637,6 @@ static void con_ic_connection_statistics_cb(DBusPendingCall *pending,
 	con_ic_statistics_event_set_rx_bytes(event, rx_bytes);
 	con_ic_statistics_event_set_tx_bytes(event, tx_bytes);
 
-	g_assert(CON_IC_IS_STATISTICS_EVENT(event));
-
 	g_signal_emit(connection,
 		      CON_IC_CONNECTION_GET_CLASS(connection)->statistics_signal_id,
 		      0, event);
@@ -901,19 +895,25 @@ ConIcProxyMode con_ic_connection_get_proxy_mode(ConIcConnection *connection)
 {
 	char *s = NULL;
 	GConfClient *gconf = gconf_client_get_default();
+	char *escaped;
+	char *path;
 
 	/* FIXME: use dbus proxy signals as soon as icd sends them */
 
-	s = gconf_client_get_string(gconf, "/system/proxy/mode", NULL);
+	escaped = gconf_escape_key (connection->iap_id, -1);
+	path = g_strconcat (ICD_GCONF_PATH, "/", escaped, "/proxytype", NULL );
+	g_free (escaped);
+	s = gconf_client_get_string(gconf, path, NULL);
+	g_free (path);
 
 	if (!s)
 		goto exit;
 	
-	if (strcmp(s, "none") == 0) {
+	if (strcmp(s, "NONE") == 0) {
 		connection->proxy_mode = CON_IC_PROXY_MODE_NONE;
-	} else if (strcmp(s, "manual") == 0) {
+	} else if (strcmp(s, "MANUAL") == 0) {
 		connection->proxy_mode = CON_IC_PROXY_MODE_MANUAL;
-	} else if (strcmp(s, "auto") == 0) {
+	} else if (strcmp(s, "AUTOCONF") == 0) {
 		connection->proxy_mode = CON_IC_PROXY_MODE_AUTO;
 	} else {
 		connection->proxy_mode = CON_IC_PROXY_MODE_NONE;
@@ -929,13 +929,18 @@ exit:
 static const gchar *con_ic_connection_get_proxy_http_host(ConIcConnection *connection)
 {
 	GConfClient *gconf = gconf_client_get_default();
+	char *escaped = gconf_escape_key (connection->iap_id, -1);
+	char *path = g_strconcat (ICD_GCONF_PATH, "/", escaped,
+				  "/proxy_http", NULL);
+
+	g_free (escaped);
 
 	/* FIXME: use dbus proxy signals as soon as icd sends them */
 
 	connection->http_host = gconf_client_get_string(gconf,
-							"/system/http_proxy/host",
+							path,
 							NULL);
-
+	g_free (path);
 	g_object_unref(gconf);
 	return connection->http_host;
 }
@@ -943,13 +948,18 @@ static const gchar *con_ic_connection_get_proxy_http_host(ConIcConnection *conne
 static gint con_ic_connection_get_proxy_http_port(ConIcConnection *connection)
 {
 	GConfClient *gconf = gconf_client_get_default();
+	char *escaped = gconf_escape_key (connection->iap_id, -1);
+	char *path = g_strconcat (ICD_GCONF_PATH, "/", escaped,
+				  "/proxy_http_port", NULL);
+
+	g_free (escaped);
 
 	/* FIXME: use dbus proxy signals as soon as icd sends them */
 
 	connection->http_port = gconf_client_get_int(gconf,
-						     "/system/http_proxy/port",
+						     path,
 						     NULL);
-
+	g_free (path);
 	g_object_unref(gconf);
 	return connection->http_port;
 }
@@ -957,13 +967,18 @@ static gint con_ic_connection_get_proxy_http_port(ConIcConnection *connection)
 static const gchar *con_ic_connection_get_proxy_ftp_host(ConIcConnection *connection)
 {
 	GConfClient *gconf = gconf_client_get_default();
+	char *escaped = gconf_escape_key (connection->iap_id, -1);
+	char *path = g_strconcat (ICD_GCONF_PATH, "/", escaped,
+				  "/proxy_ftp", NULL);
+
+	g_free (escaped);
 
 	/* FIXME: use dbus proxy signals as soon as icd sends them */
 
 	connection->ftp_host = gconf_client_get_string(gconf,
-						       "/system/proxy/ftp_host",
+						       path,
 						       NULL);
-
+	g_free (path);
 	g_object_unref(gconf);
 	return connection->ftp_host;
 }
@@ -971,13 +986,18 @@ static const gchar *con_ic_connection_get_proxy_ftp_host(ConIcConnection *connec
 static gint con_ic_connection_get_proxy_ftp_port(ConIcConnection *connection)
 {
 	GConfClient *gconf = gconf_client_get_default();
+	char *escaped = gconf_escape_key (connection->iap_id, -1);
+	char *path = g_strconcat (ICD_GCONF_PATH, "/", escaped,
+				  "/proxy_ftp_port", NULL);
+
+	g_free (escaped);
 
 	/* FIXME: use dbus proxy signals as soon as icd sends them */
 
 	connection->ftp_port = gconf_client_get_int(gconf,
-						    "/system/proxy/ftp_port",
+						    path,
 						    NULL);
-
+	g_free (path);
 	g_object_unref(gconf);
 	return connection->ftp_port;
 }
@@ -985,13 +1005,18 @@ static gint con_ic_connection_get_proxy_ftp_port(ConIcConnection *connection)
 static const gchar *con_ic_connection_get_proxy_https_host(ConIcConnection *connection)
 {
 	GConfClient *gconf = gconf_client_get_default();
+	char *escaped = gconf_escape_key (connection->iap_id, -1);
+	char *path = g_strconcat (ICD_GCONF_PATH, "/", escaped,
+				  "/proxy_https", NULL);
+
+	g_free (escaped);
 
 	/* FIXME: use dbus proxy signals as soon as icd sends them */
 
 	connection->https_host = gconf_client_get_string(gconf,
-							"/system/proxy/secure_host",
+							 path,
 							NULL);
-
+	g_free (path);
 	g_object_unref(gconf);
 	return connection->https_host;
 }
@@ -999,13 +1024,18 @@ static const gchar *con_ic_connection_get_proxy_https_host(ConIcConnection *conn
 static gint con_ic_connection_get_proxy_https_port(ConIcConnection *connection)
 {
 	GConfClient *gconf = gconf_client_get_default();
+	char *escaped = gconf_escape_key (connection->iap_id, -1);
+	char *path = g_strconcat (ICD_GCONF_PATH, "/", escaped,
+				  "/proxy_https_port", NULL);
+
+	g_free (escaped);
 
 	/* FIXME: use dbus proxy signals as soon as icd sends them */
 
 	connection->https_port = gconf_client_get_int(gconf,
-							"/system/proxy/secure_port",
-							NULL);
-
+						      path,
+						      NULL);
+	g_free (path);
 	g_object_unref(gconf);
 	return connection->https_port;
 }
@@ -1013,13 +1043,18 @@ static gint con_ic_connection_get_proxy_https_port(ConIcConnection *connection)
 static const gchar *con_ic_connection_get_proxy_socks_host(ConIcConnection *connection)
 {
 	GConfClient *gconf = gconf_client_get_default();
+	char *escaped = gconf_escape_key (connection->iap_id, -1);
+	char *path = g_strconcat (ICD_GCONF_PATH, "/", escaped,
+				  "/proxy_socks", NULL);
+
+	g_free (escaped);
 
 	/* FIXME: use dbus proxy signals as soon as icd sends them */
 
 	connection->socks_host = gconf_client_get_string(gconf,
-							"/system/proxy/socks_host",
-							NULL);
-
+							 path,
+							 NULL);
+	g_free (path);
 	g_object_unref(gconf);
 	return connection->socks_host;
 }
@@ -1027,13 +1062,19 @@ static const gchar *con_ic_connection_get_proxy_socks_host(ConIcConnection *conn
 static gint con_ic_connection_get_proxy_socks_port(ConIcConnection *connection)
 {
 	GConfClient *gconf = gconf_client_get_default();
+	char *escaped = gconf_escape_key (connection->iap_id, -1);
+	char *path = g_strconcat (ICD_GCONF_PATH, "/", escaped,
+				  "/proxy_socks_port", NULL);
+
+	g_free (escaped);
 
 	/* FIXME: use dbus proxy signals as soon as icd sends them */
 
 	connection->socks_port = gconf_client_get_int(gconf,
-						      "/system/proxy/socks_port",
+						      path,
 						      NULL);
 
+	g_free (path);
 	g_object_unref(gconf);
 	return connection->socks_port;
 }
@@ -1041,13 +1082,18 @@ static gint con_ic_connection_get_proxy_socks_port(ConIcConnection *connection)
 static const gchar *con_ic_connection_get_proxy_rtsp_host(ConIcConnection *connection)
 {
 	GConfClient *gconf = gconf_client_get_default();
+	char *escaped = gconf_escape_key (connection->iap_id, -1);
+	char *path = g_strconcat (ICD_GCONF_PATH, "/", escaped,
+				  "/proxy_rtsp", NULL);
+
+	g_free (escaped);
 
 	/* FIXME: use dbus proxy signals as soon as icd sends them */
 
 	connection->rtsp_host = gconf_client_get_string(gconf,
-							"/system/proxy/rtsp_host",
+							path,
 							NULL);
-
+	g_free (path);
 	g_object_unref(gconf);
 	return connection->rtsp_host;
 }
@@ -1055,13 +1101,18 @@ static const gchar *con_ic_connection_get_proxy_rtsp_host(ConIcConnection *conne
 static gint con_ic_connection_get_proxy_rtsp_port(ConIcConnection *connection)
 {
 	GConfClient *gconf = gconf_client_get_default();
+	char *escaped = gconf_escape_key (connection->iap_id, -1);
+	char *path = g_strconcat (ICD_GCONF_PATH, "/", escaped,
+				  "/proxy_rtsp_port", NULL);
+
+	g_free (escaped);
 
 	/* FIXME: use dbus proxy signals as soon as icd sends them */
 
 	connection->rtsp_port = gconf_client_get_int(gconf,
-							"/system/proxy/rtsp_port",
-							NULL);
-
+						     path,
+						     NULL);
+	g_free (path);
 	g_object_unref(gconf);
 	return connection->rtsp_port;
 }
@@ -1070,13 +1121,18 @@ static gint con_ic_connection_get_proxy_rtsp_port(ConIcConnection *connection)
 const gchar *con_ic_connection_get_proxy_autoconfig_url(ConIcConnection *connection)
 {
 	GConfClient *gconf = gconf_client_get_default();
+	char *escaped = gconf_escape_key (connection->iap_id, -1);
+	char *path = g_strconcat (ICD_GCONF_PATH, "/", escaped,
+				  "/autoconf_url", NULL);
+
+	g_free (escaped);
 
 	/* FIXME: use dbus proxy signals as soon as icd sends them */
 
 	connection->http_host = gconf_client_get_string(gconf,
-							"/system/http_proxy/host",
+							path,
 							NULL);
-
+	g_free (path);
 	g_object_unref(gconf);
 	return connection->http_host;
 	return NULL;
@@ -1144,11 +1200,15 @@ gint con_ic_connection_get_proxy_port(ConIcConnection* connection,
 GSList *con_ic_connection_get_proxy_ignore_hosts(ConIcConnection *connection)
 {
 	GConfClient *gconf = gconf_client_get_default();
+	char *escaped = gconf_escape_key (connection->iap_id, -1);
+	char *path = g_strconcat (ICD_GCONF_PATH, "/", escaped,
+				  "/omit_proxy", NULL);
 	GSList *list;
-	
-	list = gconf_client_get_list(gconf, "/system/http_proxy/ignore_hosts",
-			      GCONF_VALUE_STRING, NULL);
 
+	g_free (escaped);
+	list = gconf_client_get_list(gconf, path,
+				     GCONF_VALUE_STRING, NULL);
+	g_free (path);
 	g_object_unref(gconf);
 	return list;
 }
@@ -1169,9 +1229,9 @@ GSList *con_ic_connection_get_all_iaps(ConIcConnection *connection)
 		id = gconf_unescape_key(strrchr(entry->data, '/')+1, -1);
 		g_free(entry->data);
 		if (id != NULL &&
-		    strncmp (id, "[EasyWLAN", 9)) {
-		  iap = con_ic_iap_new(id);
-		  newl = g_slist_prepend (newl, iap);
+		    strncmp (id, "[Easy", 5)) {
+		  if ((iap = con_ic_iap_new(id)) != NULL)
+		    newl = g_slist_prepend (newl, iap);
 		}
 		g_free (id);
 	}
